pitchtools.PitchClassSegment
============================

.. abjad-lineage:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment

.. autoclass:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.alpha
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.count
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.custom_identifier
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.from_selection
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.has_duplicates
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.index
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.invert
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.is_equivalent_under_transposition
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.item_class
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.make_notes
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.multiply
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.retrograde
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.rotate
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.transpose
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__add__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__contains__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__eq__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__format__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__getitem__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__getslice__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__hash__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__iter__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__len__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__makenew__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__mul__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__ne__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__repr__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__rmul__
      ~abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__str__

Bases
-----

- :py:class:`pitchtools.Segment <abjad.tools.pitchtools.Segment.Segment>`

- :py:class:`datastructuretools.TypedTuple <abjad.tools.datastructuretools.TypedTuple.TypedTuple>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.has_duplicates
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.item_class
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.custom_identifier
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.alpha
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.count
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.index
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.invert
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.is_equivalent_under_transposition
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.make_notes
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.multiply
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.retrograde
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.rotate
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.transpose
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__getslice__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__makenew__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__mul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__rmul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment.__str__
   :noindex:
